==> domoticz-2020.2.tar.gz: domoticz-2020.2/README.md <==
# Domoticz

Domoticz is a Home Automation System that lets you monitor and configure various devices like: Lights, Switches, various sensors/meters like Temperature, Rain, Wind, UV, Electra, Gas, Water and much more. Notifications/Alerts can be sent to any mobile device

## Multi platform: Linux/Windows/Embedded Devices

This system is designed to operate in various operating systems.
The user-interface is a scalable HTML5 web frontend, and is automatically adapted for Desktop and Mobile Devices.
Compatible with all recent browsers

Some Information
- Hardware: RFXCOM Transceiver, Z-Wave, P1 Smart Meter, YouLess Meter, Pulse Counters, 1-Wire, Philips Hue and a lot more....
- Extended logging
- iPhone / Android / Windows 10 (Phone & Desktop) push notifications
- Auto Learning sensors/switches
- Manual creation of switch codes
- Share / Use external devices
- Designed for simplicity

## Support

Your first place for support is the [Domoticz Forum](http://www.domoticz.com/forum)

The Github issue tracker is NOT for end-user support.

## Donations
Donations are more than welcome and will be used to buy new hardware, devices, sensors, hosting and coffee.
If you like the product or encourage the development, please use thelink:

[![paypal](https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=6S2CXM772QY84&currency_code=EUR&source=url)

# More information
* Website: http://www.domoticz.com
* Forum http://www.domoticz.com/forum
* Wiki http://www.domoticz.com/wiki

### Build Status

Status | Operating system
------------ | -------------
[![Status Linux](https://travis-ci.org/domoticz/domoticz.svg?branch=master)](https://travis-ci.org/domoticz/domoticz) | Linux x86_64
[![Status Windows](https://ci.appveyor.com/api/projects/status/fskiwvjs1q7svwq9?svg=true)](https://ci.appveyor.com/project/gizmocuz/domoticz) | Windows

==> domoticz-2022.1.tar.gz: domoticz-2022.1/README.md <==
# Domoticz

Domoticz is a Home Automation System that lets you monitor and configure various devices like: Lights, Switches, various sensors/meters like Temperature, Rain, Wind, UV, Electra, Gas, Water and much more. Notifications/Alerts can be sent to any mobile device

## Multi platform: Linux/Windows/Embedded Devices

This system is designed to operate in various operating systems.
The user-interface is a scalable HTML5 web frontend, and is automatically adapted for Desktop and Mobile Devices.
Compatible with all recent browsers

Some Information
- Hardware: RFXCOM Transceiver, Z-Wave, P1 Smart Meter, YouLess Meter, Pulse Counters, 1-Wire, Philips Hue and a lot more....
- Extended logging
- iPhone / Android / Windows 10 (Phone & Desktop) push notifications
- Auto Learning sensors/switches
- Manual creation of switch codes
- Share / Use external devices
- Designed for simplicity

## Support

Your first place for support is the [Domoticz Forum](http://www.domoticz.com/forum)

The Github issue tracker is NOT for end-user support.

## Donations
Donations are more than welcome and will be used to buy new hardware, devices, sensors, hosting and coffee.
If you like the product or encourage the development, please use thelink:

[![paypal](https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif)](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=6S2CXM772QY84&currency_code=EUR&source=url)

# More information
* Website: http://www.domoticz.com
* Forum http://www.domoticz.com/forum
* Wiki http://www.domoticz.com/wiki

### Build Status

Status | Operating system
------------ | -------------
[![Status Linux](https://travis-ci.com/domoticz/domoticz.svg?branch=master)](https://travis-ci.com/domoticz/domoticz) | Linux x86_64
[![Status Windows](https://ci.appveyor.com/api/projects/status/fskiwvjs1q7svwq9?svg=true)](https://ci.appveyor.com/project/gizmocuz/domoticz) | Windows
